"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextMenu = void 0;
const React = require("react");
class ContextMenu extends React.Component {
    constructor(props) {
        super(props);
        this.handleContextMenuOnTarget = (e) => {
            e.preventDefault();
            this.openContextMenu(e.nativeEvent);
        };
        this.handleContextMenuOnWindow = (e) => {
            const target = e.target;
            if (this.elementContainer.contains(target) || this.elementContextMenu.contains(target)) {
                e.preventDefault();
                this.openContextMenu(e);
            }
            else {
                this.closeContextMenu();
            }
        };
        this.handleClickOnWindow = (e) => {
            const target = e.target;
            if (this.elementContextMenu.contains(target)) {
                if (target.classList.contains('dropdown-item') && !target.classList.contains('disabled')) {
                    this.closeContextMenu();
                }
            }
            else {
                this.closeContextMenu();
            }
        };
        this.openContextMenu = (e) => {
            const menu = this.elementContextMenu.querySelector('div.dropdown-menu');
            if (menu) {
                const rect = this.elementTarget.getBoundingClientRect();
                console.log(rect, e.x, e.y, e.screenX, e.screenY);
                console.log(e.y - rect.top, e.x - rect.left);
                menu.style.display = 'block';
                menu.style.position = 'absolute';
                menu.style.top = `${e.y - rect.top}px`;
                menu.style.left = `${e.x - rect.left}px`;
            }
            else {
                console.error('ContextMenu.menu has no div.dropdown-menu');
            }
        };
        this.closeContextMenu = () => {
            const menu = this.elementContextMenu.querySelector('div.dropdown-menu');
            if (menu) {
                menu.style.display = 'none';
                menu.style.position = 'absolute';
                menu.style.top = `0`;
                menu.style.left = `0`;
            }
            else {
                console.error('ContextMenu.menu has no div.dropdown-menu');
            }
        };
        this.state = {};
    }
    componentDidMount() {
        window.addEventListener('click', this.handleClickOnWindow);
        window.addEventListener('contextmenu', this.handleContextMenuOnWindow);
    }
    shouldComponentUpdate(nextProps, nextState, nextContext) {
        return true;
    }
    componentWillUnmount() {
        window.removeEventListener('click', this.handleClickOnWindow);
        window.removeEventListener('contextmenu', this.handleContextMenuOnWindow);
    }
    componentDidCatch(error, errorInfo) { }
    render() {
        const { menu, children } = this.props;
        return (React.createElement("div", { ref: (e) => (this.elementContainer = e) },
            React.createElement("div", { ref: (e) => (this.elementContextMenu = e), style: { position: 'relative', top: 0, left: 0, bottom: 0, right: 0, userSelect: 'none' } }, menu),
            React.createElement("div", { ref: (e) => (this.elementTarget = e), onContextMenu: this.handleContextMenuOnTarget }, children)));
    }
}
exports.ContextMenu = ContextMenu;
//# sourceMappingURL=ContextMenu.js.map